==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Klepněte pro přistoupení k tomuto zařízení z jiných aplikací.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="57"/>
        <source>Click to eject this disc.</source>
        <translation>Klepněte pro vysunutí tohoto disku.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="185"/>
        <source>Removable media/devices manager</source>
        <translation>Správce odstranitelných nosičů/zařízení</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="278"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; je zapojeno.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="297"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; je odstraněno.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="340"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; je připojeno k %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="354"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; je odpojeno&lt;br&gt;
Nyní můžete vysunout zařízení USB nebo disk CD/DVD.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="386"/>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>Nelze připojit zařízení: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="392"/>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>Zařízení &apos;%1&apos; je připojeno k %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="419"/>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>Nelze odpojit zařízení: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="423"/>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>Zařízení &apos;%1&apos; je odpojeno</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="439"/>
        <source>No devices Available.</source>
        <translation>Nejsou dostupná žádná zařízení.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Nastavení správce odstranitelných zařízení</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Chování</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Když je zařízení zapojeno</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>Ukázat vyskakovací nabídku</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Show info</source>
        <translation>Ukázat informace</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Do nothing</source>
        <translation>Nedělat nic</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_cs_CZ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Klepněte pro přistoupení k tomuto zařízení z jiných aplikací.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Klepněte pro vysunutí tohoto disku.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Správce odstranitelných nosičů/zařízení</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; je zapojeno.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; je odstraněno.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Nastavení správce odstranitelných zařízení</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Chování</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Když je zařízení zapojeno</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Ukázat vyskakovací nabídku</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Ukázat informace</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Nedělat nic</translation>
    </message>
</context>
</TS>
